# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ImageSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'actions_on_image_build_end': 'list[str]',
        'actions_on_image_build_start': 'list[str]',
        'dependency_file_info': 'V1DependencyFileInfo',
        'dockerfile': 'str',
        'image': 'str',
        'on_image_build_commands': 'list[str]',
        'relative_working_dir': 'str'
    }

    attribute_map = {
        'actions_on_image_build_end': 'actionsOnImageBuildEnd',
        'actions_on_image_build_start': 'actionsOnImageBuildStart',
        'dependency_file_info': 'dependencyFileInfo',
        'dockerfile': 'dockerfile',
        'image': 'image',
        'on_image_build_commands': 'onImageBuildCommands',
        'relative_working_dir': 'relativeWorkingDir'
    }

    def __init__(self, actions_on_image_build_end: 'list[str]' =None, actions_on_image_build_start: 'list[str]' =None, dependency_file_info: 'V1DependencyFileInfo' =None, dockerfile: 'str' =None, image: 'str' =None, on_image_build_commands: 'list[str]' =None, relative_working_dir: 'str' =None):  # noqa: E501
        """V1ImageSpec - a model defined in Swagger"""  # noqa: E501
        self._actions_on_image_build_end = None
        self._actions_on_image_build_start = None
        self._dependency_file_info = None
        self._dockerfile = None
        self._image = None
        self._on_image_build_commands = None
        self._relative_working_dir = None
        self.discriminator = None
        if actions_on_image_build_end is not None:
            self.actions_on_image_build_end = actions_on_image_build_end
        if actions_on_image_build_start is not None:
            self.actions_on_image_build_start = actions_on_image_build_start
        if dependency_file_info is not None:
            self.dependency_file_info = dependency_file_info
        if dockerfile is not None:
            self.dockerfile = dockerfile
        if image is not None:
            self.image = image
        if on_image_build_commands is not None:
            self.on_image_build_commands = on_image_build_commands
        if relative_working_dir is not None:
            self.relative_working_dir = relative_working_dir

    @property
    def actions_on_image_build_end(self) -> 'list[str]':
        """Gets the actions_on_image_build_end of this V1ImageSpec.  # noqa: E501

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes after installing dependencies from package manager.  # noqa: E501

        :return: The actions_on_image_build_end of this V1ImageSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._actions_on_image_build_end

    @actions_on_image_build_end.setter
    def actions_on_image_build_end(self, actions_on_image_build_end: 'list[str]'):
        """Sets the actions_on_image_build_end of this V1ImageSpec.

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes after installing dependencies from package manager.  # noqa: E501

        :param actions_on_image_build_end: The actions_on_image_build_end of this V1ImageSpec.  # noqa: E501
        :type: list[str]
        """

        self._actions_on_image_build_end = actions_on_image_build_end

    @property
    def actions_on_image_build_start(self) -> 'list[str]':
        """Gets the actions_on_image_build_start of this V1ImageSpec.  # noqa: E501

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes before installing dependencies from package manager.  # noqa: E501

        :return: The actions_on_image_build_start of this V1ImageSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._actions_on_image_build_start

    @actions_on_image_build_start.setter
    def actions_on_image_build_start(self, actions_on_image_build_start: 'list[str]'):
        """Sets the actions_on_image_build_start of this V1ImageSpec.

        commands passed to the image builder which are interpreted as RUN commands in a Dockerfile. Executes before installing dependencies from package manager.  # noqa: E501

        :param actions_on_image_build_start: The actions_on_image_build_start of this V1ImageSpec.  # noqa: E501
        :type: list[str]
        """

        self._actions_on_image_build_start = actions_on_image_build_start

    @property
    def dependency_file_info(self) -> 'V1DependencyFileInfo':
        """Gets the dependency_file_info of this V1ImageSpec.  # noqa: E501


        :return: The dependency_file_info of this V1ImageSpec.  # noqa: E501
        :rtype: V1DependencyFileInfo
        """
        return self._dependency_file_info

    @dependency_file_info.setter
    def dependency_file_info(self, dependency_file_info: 'V1DependencyFileInfo'):
        """Sets the dependency_file_info of this V1ImageSpec.


        :param dependency_file_info: The dependency_file_info of this V1ImageSpec.  # noqa: E501
        :type: V1DependencyFileInfo
        """

        self._dependency_file_info = dependency_file_info

    @property
    def dockerfile(self) -> 'str':
        """Gets the dockerfile of this V1ImageSpec.  # noqa: E501

        this is a relative path to a dockerfile within the build context.  # noqa: E501

        :return: The dockerfile of this V1ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._dockerfile

    @dockerfile.setter
    def dockerfile(self, dockerfile: 'str'):
        """Sets the dockerfile of this V1ImageSpec.

        this is a relative path to a dockerfile within the build context.  # noqa: E501

        :param dockerfile: The dockerfile of this V1ImageSpec.  # noqa: E501
        :type: str
        """

        self._dockerfile = dockerfile

    @property
    def image(self) -> 'str':
        """Gets the image of this V1ImageSpec.  # noqa: E501

        name of the base image to use when rendering dockerfile templates.  # noqa: E501

        :return: The image of this V1ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image: 'str'):
        """Sets the image of this V1ImageSpec.

        name of the base image to use when rendering dockerfile templates.  # noqa: E501

        :param image: The image of this V1ImageSpec.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def on_image_build_commands(self) -> 'list[str]':
        """Gets the on_image_build_commands of this V1ImageSpec.  # noqa: E501

        DEPRECATED: DO NOT USE! Build commands to add as RUN instructions. These instructions are executed before any dependencies are installed.  # noqa: E501

        :return: The on_image_build_commands of this V1ImageSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._on_image_build_commands

    @on_image_build_commands.setter
    def on_image_build_commands(self, on_image_build_commands: 'list[str]'):
        """Sets the on_image_build_commands of this V1ImageSpec.

        DEPRECATED: DO NOT USE! Build commands to add as RUN instructions. These instructions are executed before any dependencies are installed.  # noqa: E501

        :param on_image_build_commands: The on_image_build_commands of this V1ImageSpec.  # noqa: E501
        :type: list[str]
        """

        self._on_image_build_commands = on_image_build_commands

    @property
    def relative_working_dir(self) -> 'str':
        """Gets the relative_working_dir of this V1ImageSpec.  # noqa: E501


        :return: The relative_working_dir of this V1ImageSpec.  # noqa: E501
        :rtype: str
        """
        return self._relative_working_dir

    @relative_working_dir.setter
    def relative_working_dir(self, relative_working_dir: 'str'):
        """Sets the relative_working_dir of this V1ImageSpec.


        :param relative_working_dir: The relative_working_dir of this V1ImageSpec.  # noqa: E501
        :type: str
        """

        self._relative_working_dir = relative_working_dir

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ImageSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ImageSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ImageSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ImageSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class Create(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'aws': 'V1AwsDataConnection',
        'cluster_id': 'str',
        'create_index': 'bool',
        'force': 'bool',
        'gcp': 'V1GcpDataConnection',
        'id': 'str',
        'name': 'str',
        'run_cmds': 'list[str]',
        'writable': 'bool'
    }

    attribute_map = {
        'aws': 'aws',
        'cluster_id': 'clusterId',
        'create_index': 'createIndex',
        'force': 'force',
        'gcp': 'gcp',
        'id': 'id',
        'name': 'name',
        'run_cmds': 'runCmds',
        'writable': 'writable'
    }

    def __init__(self, aws: 'V1AwsDataConnection' =None, cluster_id: 'str' =None, create_index: 'bool' =None, force: 'bool' =None, gcp: 'V1GcpDataConnection' =None, id: 'str' =None, name: 'str' =None, run_cmds: 'list[str]' =None, writable: 'bool' =None):  # noqa: E501
        """Create - a model defined in Swagger"""  # noqa: E501
        self._aws = None
        self._cluster_id = None
        self._create_index = None
        self._force = None
        self._gcp = None
        self._id = None
        self._name = None
        self._run_cmds = None
        self._writable = None
        self.discriminator = None
        if aws is not None:
            self.aws = aws
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if create_index is not None:
            self.create_index = create_index
        if force is not None:
            self.force = force
        if gcp is not None:
            self.gcp = gcp
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if run_cmds is not None:
            self.run_cmds = run_cmds
        if writable is not None:
            self.writable = writable

    @property
    def aws(self) -> 'V1AwsDataConnection':
        """Gets the aws of this Create.  # noqa: E501


        :return: The aws of this Create.  # noqa: E501
        :rtype: V1AwsDataConnection
        """
        return self._aws

    @aws.setter
    def aws(self, aws: 'V1AwsDataConnection'):
        """Sets the aws of this Create.


        :param aws: The aws of this Create.  # noqa: E501
        :type: V1AwsDataConnection
        """

        self._aws = aws

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this Create.  # noqa: E501


        :return: The cluster_id of this Create.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this Create.


        :param cluster_id: The cluster_id of this Create.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def create_index(self) -> 'bool':
        """Gets the create_index of this Create.  # noqa: E501


        :return: The create_index of this Create.  # noqa: E501
        :rtype: bool
        """
        return self._create_index

    @create_index.setter
    def create_index(self, create_index: 'bool'):
        """Sets the create_index of this Create.


        :param create_index: The create_index of this Create.  # noqa: E501
        :type: bool
        """

        self._create_index = create_index

    @property
    def force(self) -> 'bool':
        """Gets the force of this Create.  # noqa: E501


        :return: The force of this Create.  # noqa: E501
        :rtype: bool
        """
        return self._force

    @force.setter
    def force(self, force: 'bool'):
        """Sets the force of this Create.


        :param force: The force of this Create.  # noqa: E501
        :type: bool
        """

        self._force = force

    @property
    def gcp(self) -> 'V1GcpDataConnection':
        """Gets the gcp of this Create.  # noqa: E501


        :return: The gcp of this Create.  # noqa: E501
        :rtype: V1GcpDataConnection
        """
        return self._gcp

    @gcp.setter
    def gcp(self, gcp: 'V1GcpDataConnection'):
        """Sets the gcp of this Create.


        :param gcp: The gcp of this Create.  # noqa: E501
        :type: V1GcpDataConnection
        """

        self._gcp = gcp

    @property
    def id(self) -> 'str':
        """Gets the id of this Create.  # noqa: E501


        :return: The id of this Create.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this Create.


        :param id: The id of this Create.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self) -> 'str':
        """Gets the name of this Create.  # noqa: E501


        :return: The name of this Create.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this Create.


        :param name: The name of this Create.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def run_cmds(self) -> 'list[str]':
        """Gets the run_cmds of this Create.  # noqa: E501


        :return: The run_cmds of this Create.  # noqa: E501
        :rtype: list[str]
        """
        return self._run_cmds

    @run_cmds.setter
    def run_cmds(self, run_cmds: 'list[str]'):
        """Sets the run_cmds of this Create.


        :param run_cmds: The run_cmds of this Create.  # noqa: E501
        :type: list[str]
        """

        self._run_cmds = run_cmds

    @property
    def writable(self) -> 'bool':
        """Gets the writable of this Create.  # noqa: E501


        :return: The writable of this Create.  # noqa: E501
        :rtype: bool
        """
        return self._writable

    @writable.setter
    def writable(self, writable: 'bool'):
        """Sets the writable of this Create.


        :param writable: The writable of this Create.  # noqa: E501
        :type: bool
        """

        self._writable = writable

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Create, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'Create') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, Create):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'Create') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class LightningappV2ServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def lightningapp_v2_service_create_lightningapp_from_gallery(self, body: 'ProjectIdGetappBody', project_id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_from_gallery  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_from_gallery(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdGetappBody body: (required)
        :param str project_id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_create_lightningapp_from_gallery_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_create_lightningapp_from_gallery_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_create_lightningapp_from_gallery_with_http_info(self, body: 'ProjectIdGetappBody', project_id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_from_gallery  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_from_gallery_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdGetappBody body: (required)
        :param str project_id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_create_lightningapp_from_gallery" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_v2_service_create_lightningapp_from_gallery`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_create_lightningapp_from_gallery`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/get-app', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_create_lightningapp_release(self, body: 'AppIdReleasesBody', project_id: 'str', app_id: 'str', **kwargs) -> 'V1LightningappRelease':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_release(body, project_id, app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AppIdReleasesBody body: (required)
        :param str project_id: (required)
        :param str app_id: (required)
        :return: V1LightningappRelease
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_create_lightningapp_release_with_http_info(body, project_id, app_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_create_lightningapp_release_with_http_info(body, project_id, app_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_create_lightningapp_release_with_http_info(self, body: 'AppIdReleasesBody', project_id: 'str', app_id: 'str', **kwargs) -> 'V1LightningappRelease':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_release_with_http_info(body, project_id, app_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AppIdReleasesBody body: (required)
        :param str project_id: (required)
        :param str app_id: (required)
        :return: V1LightningappRelease
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'app_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_create_lightningapp_release" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_v2_service_create_lightningapp_release`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_create_lightningapp_release`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if ('app_id' not in params or
                params['app_id'] is None):
            raise ValueError("Missing the required parameter `app_id` when calling `lightningapp_v2_service_create_lightningapp_release`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'app_id' in params:
            path_params['appId'] = params['app_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{appId}/releases', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LightningappRelease',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_create_lightningapp_release_instance(self, body: 'IdGetBody', project_id: 'str', app_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_release_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_release_instance(body, project_id, app_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdGetBody body: (required)
        :param str project_id: (required)
        :param str app_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_create_lightningapp_release_instance_with_http_info(body, project_id, app_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_create_lightningapp_release_instance_with_http_info(body, project_id, app_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_create_lightningapp_release_instance_with_http_info(self, body: 'IdGetBody', project_id: 'str', app_id: 'str', id: 'str', **kwargs) -> 'Externalv1LightningappInstance':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_release_instance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_release_instance_with_http_info(body, project_id, app_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param IdGetBody body: (required)
        :param str project_id: (required)
        :param str app_id: (required)
        :param str id: (required)
        :return: Externalv1LightningappInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'app_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_create_lightningapp_release_instance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_v2_service_create_lightningapp_release_instance`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_create_lightningapp_release_instance`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if ('app_id' not in params or
                params['app_id'] is None):
            raise ValueError("Missing the required parameter `app_id` when calling `lightningapp_v2_service_create_lightningapp_release_instance`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_v2_service_create_lightningapp_release_instance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'app_id' in params:
            path_params['appId'] = params['app_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{appId}/releases/{id}/get', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Externalv1LightningappInstance',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_create_lightningapp_v2(self, body: 'ProjectIdAppsv2Body', project_id: 'str', **kwargs) -> 'V1LightningappV2':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_v2(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdAppsv2Body body: (required)
        :param str project_id: (required)
        :return: V1LightningappV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_create_lightningapp_v2_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_create_lightningapp_v2_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_create_lightningapp_v2_with_http_info(self, body: 'ProjectIdAppsv2Body', project_id: 'str', **kwargs) -> 'V1LightningappV2':  # noqa: E501
        """lightningapp_v2_service_create_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_create_lightningapp_v2_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ProjectIdAppsv2Body body: (required)
        :param str project_id: (required)
        :return: V1LightningappV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_create_lightningapp_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_v2_service_create_lightningapp_v2`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_create_lightningapp_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LightningappV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_delete_lightningapp_release(self, project_id: 'str', app_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappReleaseResponse':  # noqa: E501
        """lightningapp_v2_service_delete_lightningapp_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_delete_lightningapp_release(project_id, app_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str app_id: (required)
        :param str id: (required)
        :return: V1DeleteLightningappReleaseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_delete_lightningapp_release_with_http_info(project_id, app_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_delete_lightningapp_release_with_http_info(project_id, app_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_delete_lightningapp_release_with_http_info(self, project_id: 'str', app_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappReleaseResponse':  # noqa: E501
        """lightningapp_v2_service_delete_lightningapp_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_delete_lightningapp_release_with_http_info(project_id, app_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str app_id: (required)
        :param str id: (required)
        :return: V1DeleteLightningappReleaseResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'app_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_delete_lightningapp_release" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_delete_lightningapp_release`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if ('app_id' not in params or
                params['app_id'] is None):
            raise ValueError("Missing the required parameter `app_id` when calling `lightningapp_v2_service_delete_lightningapp_release`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_v2_service_delete_lightningapp_release`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'app_id' in params:
            path_params['appId'] = params['app_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{appId}/releases/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteLightningappReleaseResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_delete_lightningapp_v2(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappV2Response':  # noqa: E501
        """lightningapp_v2_service_delete_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_delete_lightningapp_v2(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteLightningappV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_delete_lightningapp_v2_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_delete_lightningapp_v2_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_delete_lightningapp_v2_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1DeleteLightningappV2Response':  # noqa: E501
        """lightningapp_v2_service_delete_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_delete_lightningapp_v2_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1DeleteLightningappV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_delete_lightningapp_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_delete_lightningapp_v2`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_v2_service_delete_lightningapp_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1DeleteLightningappV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_get_lightningapp_release(self, project_id: 'str', app_id: 'str', id: 'str', **kwargs) -> 'V1LightningappRelease':  # noqa: E501
        """lightningapp_v2_service_get_lightningapp_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_get_lightningapp_release(project_id, app_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str app_id: (required)
        :param str id: (required)
        :return: V1LightningappRelease
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_get_lightningapp_release_with_http_info(project_id, app_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_get_lightningapp_release_with_http_info(project_id, app_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_get_lightningapp_release_with_http_info(self, project_id: 'str', app_id: 'str', id: 'str', **kwargs) -> 'V1LightningappRelease':  # noqa: E501
        """lightningapp_v2_service_get_lightningapp_release  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_get_lightningapp_release_with_http_info(project_id, app_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str app_id: (required)
        :param str id: (required)
        :return: V1LightningappRelease
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'app_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_get_lightningapp_release" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_get_lightningapp_release`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if ('app_id' not in params or
                params['app_id'] is None):
            raise ValueError("Missing the required parameter `app_id` when calling `lightningapp_v2_service_get_lightningapp_release`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_v2_service_get_lightningapp_release`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'app_id' in params:
            path_params['appId'] = params['app_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{appId}/releases/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LightningappRelease',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_get_lightningapp_source_code_download_url(self, project_id: 'str', app_id: 'str', release_id: 'str', **kwargs) -> 'V1GetLightningappSourceCodeDownloadUrlResponse':  # noqa: E501
        """lightningapp_v2_service_get_lightningapp_source_code_download_url  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_get_lightningapp_source_code_download_url(project_id, app_id, release_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str app_id: (required)
        :param str release_id: (required)
        :return: V1GetLightningappSourceCodeDownloadUrlResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_get_lightningapp_source_code_download_url_with_http_info(project_id, app_id, release_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_get_lightningapp_source_code_download_url_with_http_info(project_id, app_id, release_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_get_lightningapp_source_code_download_url_with_http_info(self, project_id: 'str', app_id: 'str', release_id: 'str', **kwargs) -> 'V1GetLightningappSourceCodeDownloadUrlResponse':  # noqa: E501
        """lightningapp_v2_service_get_lightningapp_source_code_download_url  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_get_lightningapp_source_code_download_url_with_http_info(project_id, app_id, release_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str app_id: (required)
        :param str release_id: (required)
        :return: V1GetLightningappSourceCodeDownloadUrlResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'app_id', 'release_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_get_lightningapp_source_code_download_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_get_lightningapp_source_code_download_url`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if ('app_id' not in params or
                params['app_id'] is None):
            raise ValueError("Missing the required parameter `app_id` when calling `lightningapp_v2_service_get_lightningapp_source_code_download_url`")  # noqa: E501
        # verify the required parameter 'release_id' is set
        if ('release_id' not in params or
                params['release_id'] is None):
            raise ValueError("Missing the required parameter `release_id` when calling `lightningapp_v2_service_get_lightningapp_source_code_download_url`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'app_id' in params:
            path_params['appId'] = params['app_id']  # noqa: E501
        if 'release_id' in params:
            path_params['releaseId'] = params['release_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{appId}/releases/{releaseId}/source-code', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetLightningappSourceCodeDownloadUrlResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_get_lightningapp_v2(self, project_id: 'str', id: 'str', **kwargs) -> 'V1LightningappV2':  # noqa: E501
        """lightningapp_v2_service_get_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_get_lightningapp_v2(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1LightningappV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_get_lightningapp_v2_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_get_lightningapp_v2_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_get_lightningapp_v2_with_http_info(self, project_id: 'str', id: 'str', **kwargs) -> 'V1LightningappV2':  # noqa: E501
        """lightningapp_v2_service_get_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_get_lightningapp_v2_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: V1LightningappV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_get_lightningapp_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_get_lightningapp_v2`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_v2_service_get_lightningapp_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LightningappV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_list_gallery_components(self, **kwargs) -> 'V1ListGalleryComponentsResponse':  # noqa: E501
        """lightningapp_v2_service_list_gallery_components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_list_gallery_components(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1ListGalleryComponentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_list_gallery_components_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_list_gallery_components_with_http_info(**kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_list_gallery_components_with_http_info(self, **kwargs) -> 'V1ListGalleryComponentsResponse':  # noqa: E501
        """lightningapp_v2_service_list_gallery_components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_list_gallery_components_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1ListGalleryComponentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_list_gallery_components" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/components', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListGalleryComponentsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_list_gallery_lightningapps(self, **kwargs) -> 'V1ListGalleryLightningappsResponse':  # noqa: E501
        """lightningapp_v2_service_list_gallery_lightningapps  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_list_gallery_lightningapps(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1ListGalleryLightningappsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_list_gallery_lightningapps_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_list_gallery_lightningapps_with_http_info(**kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_list_gallery_lightningapps_with_http_info(self, **kwargs) -> 'V1ListGalleryLightningappsResponse':  # noqa: E501
        """lightningapp_v2_service_list_gallery_lightningapps  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_list_gallery_lightningapps_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: V1ListGalleryLightningappsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_list_gallery_lightningapps" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/apps', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListGalleryLightningappsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_list_lightningapps_v2(self, project_id: 'str', **kwargs) -> 'V1ListLightningappsV2Response':  # noqa: E501
        """lightningapp_v2_service_list_lightningapps_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_list_lightningapps_v2(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str page_token: Pagination.
        :param str limit:
        :param str name: Filters.
        :return: V1ListLightningappsV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_list_lightningapps_v2_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_list_lightningapps_v2_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_list_lightningapps_v2_with_http_info(self, project_id: 'str', **kwargs) -> 'V1ListLightningappsV2Response':  # noqa: E501
        """lightningapp_v2_service_list_lightningapps_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_list_lightningapps_v2_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str page_token: Pagination.
        :param str limit:
        :param str name: Filters.
        :return: V1ListLightningappsV2Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_token', 'limit', 'name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_list_lightningapps_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_list_lightningapps_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'name' in params:
            query_params.append(('name', params['name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1ListLightningappsV2Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lightningapp_v2_service_update_lightningapp_v2(self, body: 'Appsv2IdBody', project_id: 'str', id: 'str', **kwargs) -> 'V1LightningappV2':  # noqa: E501
        """lightningapp_v2_service_update_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_update_lightningapp_v2(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Appsv2IdBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1LightningappV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lightningapp_v2_service_update_lightningapp_v2_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.lightningapp_v2_service_update_lightningapp_v2_with_http_info(body, project_id, id, **kwargs)  # noqa: E501
            return data

    def lightningapp_v2_service_update_lightningapp_v2_with_http_info(self, body: 'Appsv2IdBody', project_id: 'str', id: 'str', **kwargs) -> 'V1LightningappV2':  # noqa: E501
        """lightningapp_v2_service_update_lightningapp_v2  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lightningapp_v2_service_update_lightningapp_v2_with_http_info(body, project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Appsv2IdBody body: (required)
        :param str project_id: (required)
        :param str id: (required)
        :return: V1LightningappV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lightningapp_v2_service_update_lightningapp_v2" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `lightningapp_v2_service_update_lightningapp_v2`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `lightningapp_v2_service_update_lightningapp_v2`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `lightningapp_v2_service_update_lightningapp_v2`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/appsv2/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1LightningappV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1SSHPublicKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'id': 'str',
        'last_used_at': 'datetime',
        'name': 'str',
        'public_key': 'str',
        'setup_confirmed': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'id': 'id',
        'last_used_at': 'lastUsedAt',
        'name': 'name',
        'public_key': 'publicKey',
        'setup_confirmed': 'setupConfirmed',
        'type': 'type'
    }

    def __init__(self, created_at: 'datetime' =None, id: 'str' =None, last_used_at: 'datetime' =None, name: 'str' =None, public_key: 'str' =None, setup_confirmed: 'bool' =None, type: 'str' =None):  # noqa: E501
        """V1SSHPublicKey - a model defined in Swagger"""  # noqa: E501
        self._created_at = None
        self._id = None
        self._last_used_at = None
        self._name = None
        self._public_key = None
        self._setup_confirmed = None
        self._type = None
        self.discriminator = None
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if last_used_at is not None:
            self.last_used_at = last_used_at
        if name is not None:
            self.name = name
        if public_key is not None:
            self.public_key = public_key
        if setup_confirmed is not None:
            self.setup_confirmed = setup_confirmed
        if type is not None:
            self.type = type

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1SSHPublicKey.  # noqa: E501


        :return: The created_at of this V1SSHPublicKey.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1SSHPublicKey.


        :param created_at: The created_at of this V1SSHPublicKey.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self) -> 'str':
        """Gets the id of this V1SSHPublicKey.  # noqa: E501


        :return: The id of this V1SSHPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1SSHPublicKey.


        :param id: The id of this V1SSHPublicKey.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def last_used_at(self) -> 'datetime':
        """Gets the last_used_at of this V1SSHPublicKey.  # noqa: E501


        :return: The last_used_at of this V1SSHPublicKey.  # noqa: E501
        :rtype: datetime
        """
        return self._last_used_at

    @last_used_at.setter
    def last_used_at(self, last_used_at: 'datetime'):
        """Sets the last_used_at of this V1SSHPublicKey.


        :param last_used_at: The last_used_at of this V1SSHPublicKey.  # noqa: E501
        :type: datetime
        """

        self._last_used_at = last_used_at

    @property
    def name(self) -> 'str':
        """Gets the name of this V1SSHPublicKey.  # noqa: E501


        :return: The name of this V1SSHPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1SSHPublicKey.


        :param name: The name of this V1SSHPublicKey.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def public_key(self) -> 'str':
        """Gets the public_key of this V1SSHPublicKey.  # noqa: E501


        :return: The public_key of this V1SSHPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key: 'str'):
        """Sets the public_key of this V1SSHPublicKey.


        :param public_key: The public_key of this V1SSHPublicKey.  # noqa: E501
        :type: str
        """

        self._public_key = public_key

    @property
    def setup_confirmed(self) -> 'bool':
        """Gets the setup_confirmed of this V1SSHPublicKey.  # noqa: E501


        :return: The setup_confirmed of this V1SSHPublicKey.  # noqa: E501
        :rtype: bool
        """
        return self._setup_confirmed

    @setup_confirmed.setter
    def setup_confirmed(self, setup_confirmed: 'bool'):
        """Sets the setup_confirmed of this V1SSHPublicKey.


        :param setup_confirmed: The setup_confirmed of this V1SSHPublicKey.  # noqa: E501
        :type: bool
        """

        self._setup_confirmed = setup_confirmed

    @property
    def type(self) -> 'str':
        """Gets the type of this V1SSHPublicKey.  # noqa: E501


        :return: The type of this V1SSHPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type: 'str'):
        """Sets the type of this V1SSHPublicKey.


        :param type: The type of this V1SSHPublicKey.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1SSHPublicKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1SSHPublicKey') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SSHPublicKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1SSHPublicKey') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

import re  # noqa: F401
from typing import TYPE_CHECKING, Any

# python 2 and python 3 compatibility library
import six

from lightning_cloud.openapi.api_client import ApiClient

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class BillingServiceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def billing_service_create_checkout_session(self, body: 'BillingCheckoutBody1', project_id: 'str', **kwargs) -> 'V1CreateCheckoutSessionResponse':  # noqa: E501
        """billing_service_create_checkout_session  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_create_checkout_session(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingCheckoutBody1 body: (required)
        :param str project_id: (required)
        :return: V1CreateCheckoutSessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_create_checkout_session_with_http_info(body, project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_create_checkout_session_with_http_info(body, project_id, **kwargs)  # noqa: E501
            return data

    def billing_service_create_checkout_session_with_http_info(self, body: 'BillingCheckoutBody1', project_id: 'str', **kwargs) -> 'V1CreateCheckoutSessionResponse':  # noqa: E501
        """billing_service_create_checkout_session  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_create_checkout_session_with_http_info(body, project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingCheckoutBody1 body: (required)
        :param str project_id: (required)
        :return: V1CreateCheckoutSessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_create_checkout_session" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `billing_service_create_checkout_session`")  # noqa: E501
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `billing_service_create_checkout_session`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/billing/checkout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CreateCheckoutSessionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_create_org_checkout_session(self, body: 'BillingCheckoutBody', org_id: 'str', **kwargs) -> 'V1CreateCheckoutSessionResponse':  # noqa: E501
        """billing_service_create_org_checkout_session  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_create_org_checkout_session(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingCheckoutBody body: (required)
        :param str org_id: (required)
        :return: V1CreateCheckoutSessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_create_org_checkout_session_with_http_info(body, org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_create_org_checkout_session_with_http_info(body, org_id, **kwargs)  # noqa: E501
            return data

    def billing_service_create_org_checkout_session_with_http_info(self, body: 'BillingCheckoutBody', org_id: 'str', **kwargs) -> 'V1CreateCheckoutSessionResponse':  # noqa: E501
        """billing_service_create_org_checkout_session  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_create_org_checkout_session_with_http_info(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingCheckoutBody body: (required)
        :param str org_id: (required)
        :return: V1CreateCheckoutSessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_create_org_checkout_session" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `billing_service_create_org_checkout_session`")  # noqa: E501
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `billing_service_create_org_checkout_session`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/billing/checkout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CreateCheckoutSessionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_create_subscription_checkout_session(self, body: 'SubscriptionCheckoutBody', org_id: 'str', **kwargs) -> 'V1CreateSubscriptionCheckoutSessionResponse':  # noqa: E501
        """billing_service_create_subscription_checkout_session  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_create_subscription_checkout_session(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SubscriptionCheckoutBody body: (required)
        :param str org_id: (required)
        :return: V1CreateSubscriptionCheckoutSessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_create_subscription_checkout_session_with_http_info(body, org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_create_subscription_checkout_session_with_http_info(body, org_id, **kwargs)  # noqa: E501
            return data

    def billing_service_create_subscription_checkout_session_with_http_info(self, body: 'SubscriptionCheckoutBody', org_id: 'str', **kwargs) -> 'V1CreateSubscriptionCheckoutSessionResponse':  # noqa: E501
        """billing_service_create_subscription_checkout_session  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_create_subscription_checkout_session_with_http_info(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param SubscriptionCheckoutBody body: (required)
        :param str org_id: (required)
        :return: V1CreateSubscriptionCheckoutSessionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_create_subscription_checkout_session" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `billing_service_create_subscription_checkout_session`")  # noqa: E501
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `billing_service_create_subscription_checkout_session`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/billing/subscription/checkout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1CreateSubscriptionCheckoutSessionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_get_billing_subscription(self, org_id: 'str', **kwargs) -> 'V1BillingSubscription':  # noqa: E501
        """Billing subscription endpoint that returns the organization's current subscription and its features  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_billing_subscription(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1BillingSubscription
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_get_billing_subscription_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_get_billing_subscription_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def billing_service_get_billing_subscription_with_http_info(self, org_id: 'str', **kwargs) -> 'V1BillingSubscription':  # noqa: E501
        """Billing subscription endpoint that returns the organization's current subscription and its features  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_billing_subscription_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1BillingSubscription
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_get_billing_subscription" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `billing_service_get_billing_subscription`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/billing/subscription', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1BillingSubscription',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_get_org_balance(self, org_id: 'str', **kwargs) -> 'V1GetProjectBalanceResponse':  # noqa: E501
        """billing_service_get_org_balance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_org_balance(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1GetProjectBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_get_org_balance_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_get_org_balance_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def billing_service_get_org_balance_with_http_info(self, org_id: 'str', **kwargs) -> 'V1GetProjectBalanceResponse':  # noqa: E501
        """billing_service_get_org_balance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_org_balance_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :return: V1GetProjectBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_get_org_balance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `billing_service_get_org_balance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/billing/balance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetProjectBalanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_get_project_balance(self, project_id: 'str', **kwargs) -> 'V1GetProjectBalanceResponse':  # noqa: E501
        """billing_service_get_project_balance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_project_balance(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1GetProjectBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_get_project_balance_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_get_project_balance_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def billing_service_get_project_balance_with_http_info(self, project_id: 'str', **kwargs) -> 'V1GetProjectBalanceResponse':  # noqa: E501
        """billing_service_get_project_balance  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_project_balance_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: V1GetProjectBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_get_project_balance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `billing_service_get_project_balance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/billing/balance', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetProjectBalanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_get_project_compute_usage(self, project_id: 'str', **kwargs) -> 'V1GetProjectComputeUsageResponse':  # noqa: E501
        """Compute usage, deprecate?  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_project_compute_usage(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param datetime _from:
        :param datetime to:
        :param str resource_id:
        :return: V1GetProjectComputeUsageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_get_project_compute_usage_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_get_project_compute_usage_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def billing_service_get_project_compute_usage_with_http_info(self, project_id: 'str', **kwargs) -> 'V1GetProjectComputeUsageResponse':  # noqa: E501
        """Compute usage, deprecate?  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_project_compute_usage_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param datetime _from:
        :param datetime to:
        :param str resource_id:
        :return: V1GetProjectComputeUsageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', '_from', 'to', 'resource_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_get_project_compute_usage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if ('project_id' not in params or
                params['project_id'] is None):
            raise ValueError("Missing the required parameter `project_id` when calling `billing_service_get_project_compute_usage`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501
        if 'resource_id' in params:
            query_params.append(('resourceId', params['resource_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/billing/compute', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1GetProjectComputeUsageResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_get_usage_report(self, **kwargs) -> 'V1UsageReport':  # noqa: E501
        """Usage report endpoint to get credits spending information. Provides credits consumption data by particular project according to filters given.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_usage_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id:
        :param str project_id:
        :param str cluster_id:
        :param str resource_type:
        :param str resource_id:
        :param datetime _from:
        :param datetime to:
        :return: V1UsageReport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_get_usage_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_get_usage_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def billing_service_get_usage_report_with_http_info(self, **kwargs) -> 'V1UsageReport':  # noqa: E501
        """Usage report endpoint to get credits spending information. Provides credits consumption data by particular project according to filters given.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_get_usage_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id:
        :param str project_id:
        :param str cluster_id:
        :param str resource_type:
        :param str resource_id:
        :param datetime _from:
        :param datetime to:
        :return: V1UsageReport
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'project_id', 'cluster_id', 'resource_type', 'resource_id', '_from', 'to']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_get_usage_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'org_id' in params:
            query_params.append(('orgId', params['org_id']))  # noqa: E501
        if 'project_id' in params:
            query_params.append(('projectId', params['project_id']))  # noqa: E501
        if 'cluster_id' in params:
            query_params.append(('clusterId', params['cluster_id']))  # noqa: E501
        if 'resource_type' in params:
            query_params.append(('resourceType', params['resource_type']))  # noqa: E501
        if 'resource_id' in params:
            query_params.append(('resourceId', params['resource_id']))  # noqa: E501
        if '_from' in params:
            query_params.append(('from', params['_from']))  # noqa: E501
        if 'to' in params:
            query_params.append(('to', params['to']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/billing/usage-report', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1UsageReport',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_quote_subscription(self, org_id: 'str', **kwargs) -> 'V1QuoteSubscriptionResponse':  # noqa: E501
        """billing_service_quote_subscription  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_quote_subscription(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str product_id:
        :return: V1QuoteSubscriptionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_quote_subscription_with_http_info(org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_quote_subscription_with_http_info(org_id, **kwargs)  # noqa: E501
            return data

    def billing_service_quote_subscription_with_http_info(self, org_id: 'str', **kwargs) -> 'V1QuoteSubscriptionResponse':  # noqa: E501
        """billing_service_quote_subscription  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_quote_subscription_with_http_info(org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str org_id: (required)
        :param str product_id:
        :return: V1QuoteSubscriptionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['org_id', 'product_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_quote_subscription" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `billing_service_quote_subscription`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []
        if 'product_id' in params:
            query_params.append(('productId', params['product_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/billing/subscription/quote', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1QuoteSubscriptionResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_transfer_org_balance(self, body: 'BillingTransferBody', org_src_id: 'str', **kwargs) -> 'V1TransferOrgBalanceResponse':  # noqa: E501
        """Org wallet management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_transfer_org_balance(body, org_src_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingTransferBody body: (required)
        :param str org_src_id: (required)
        :return: V1TransferOrgBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_transfer_org_balance_with_http_info(body, org_src_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_transfer_org_balance_with_http_info(body, org_src_id, **kwargs)  # noqa: E501
            return data

    def billing_service_transfer_org_balance_with_http_info(self, body: 'BillingTransferBody', org_src_id: 'str', **kwargs) -> 'V1TransferOrgBalanceResponse':  # noqa: E501
        """Org wallet management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_transfer_org_balance_with_http_info(body, org_src_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingTransferBody body: (required)
        :param str org_src_id: (required)
        :return: V1TransferOrgBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_src_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_transfer_org_balance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `billing_service_transfer_org_balance`")  # noqa: E501
        # verify the required parameter 'org_src_id' is set
        if ('org_src_id' not in params or
                params['org_src_id'] is None):
            raise ValueError("Missing the required parameter `org_src_id` when calling `billing_service_transfer_org_balance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_src_id' in params:
            path_params['orgSrcId'] = params['org_src_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgSrcId}/billing/transfer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1TransferOrgBalanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_transfer_project_balance(self, body: 'BillingTransferBody1', project_src_id: 'str', **kwargs) -> 'V1TransferProjectBalanceResponse':  # noqa: E501
        """Project wallet management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_transfer_project_balance(body, project_src_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingTransferBody1 body: (required)
        :param str project_src_id: (required)
        :return: V1TransferProjectBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_transfer_project_balance_with_http_info(body, project_src_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_transfer_project_balance_with_http_info(body, project_src_id, **kwargs)  # noqa: E501
            return data

    def billing_service_transfer_project_balance_with_http_info(self, body: 'BillingTransferBody1', project_src_id: 'str', **kwargs) -> 'V1TransferProjectBalanceResponse':  # noqa: E501
        """Project wallet management  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_transfer_project_balance_with_http_info(body, project_src_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingTransferBody1 body: (required)
        :param str project_src_id: (required)
        :return: V1TransferProjectBalanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'project_src_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_transfer_project_balance" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `billing_service_transfer_project_balance`")  # noqa: E501
        # verify the required parameter 'project_src_id' is set
        if ('project_src_id' not in params or
                params['project_src_id'] is None):
            raise ValueError("Missing the required parameter `project_src_id` when calling `billing_service_transfer_project_balance`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_src_id' in params:
            path_params['projectSrcId'] = params['project_src_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectSrcId}/billing/transfer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1TransferProjectBalanceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def billing_service_update_billing_subscription(self, body: 'BillingSubscriptionBody', org_id: 'str', **kwargs) -> 'V1BillingSubscription':  # noqa: E501
        """billing_service_update_billing_subscription  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_update_billing_subscription(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingSubscriptionBody body: (required)
        :param str org_id: (required)
        :return: V1BillingSubscription
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.billing_service_update_billing_subscription_with_http_info(body, org_id, **kwargs)  # noqa: E501
        else:
            (data) = self.billing_service_update_billing_subscription_with_http_info(body, org_id, **kwargs)  # noqa: E501
            return data

    def billing_service_update_billing_subscription_with_http_info(self, body: 'BillingSubscriptionBody', org_id: 'str', **kwargs) -> 'V1BillingSubscription':  # noqa: E501
        """billing_service_update_billing_subscription  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.billing_service_update_billing_subscription_with_http_info(body, org_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BillingSubscriptionBody body: (required)
        :param str org_id: (required)
        :return: V1BillingSubscription
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'org_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method billing_service_update_billing_subscription" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `billing_service_update_billing_subscription`")  # noqa: E501
        # verify the required parameter 'org_id' is set
        if ('org_id' not in params or
                params['org_id'] is None):
            raise ValueError("Missing the required parameter `org_id` when calling `billing_service_update_billing_subscription`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'org_id' in params:
            path_params['orgId'] = params['org_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/orgs/{orgId}/billing/subscription', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='V1BillingSubscription',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1ModelVersionArchive(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'created_at': 'datetime',
        'downloads': 'str',
        'metadata': 'dict(str, str)',
        'model_id': 'str',
        'project_id': 'str',
        'updated_at': 'datetime',
        'version': 'str'
    }

    attribute_map = {
        'cluster_id': 'clusterId',
        'created_at': 'createdAt',
        'downloads': 'downloads',
        'metadata': 'metadata',
        'model_id': 'modelId',
        'project_id': 'projectId',
        'updated_at': 'updatedAt',
        'version': 'version'
    }

    def __init__(self, cluster_id: 'str' =None, created_at: 'datetime' =None, downloads: 'str' =None, metadata: 'dict(str, str)' =None, model_id: 'str' =None, project_id: 'str' =None, updated_at: 'datetime' =None, version: 'str' =None):  # noqa: E501
        """V1ModelVersionArchive - a model defined in Swagger"""  # noqa: E501
        self._cluster_id = None
        self._created_at = None
        self._downloads = None
        self._metadata = None
        self._model_id = None
        self._project_id = None
        self._updated_at = None
        self._version = None
        self.discriminator = None
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if created_at is not None:
            self.created_at = created_at
        if downloads is not None:
            self.downloads = downloads
        if metadata is not None:
            self.metadata = metadata
        if model_id is not None:
            self.model_id = model_id
        if project_id is not None:
            self.project_id = project_id
        if updated_at is not None:
            self.updated_at = updated_at
        if version is not None:
            self.version = version

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this V1ModelVersionArchive.  # noqa: E501


        :return: The cluster_id of this V1ModelVersionArchive.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this V1ModelVersionArchive.


        :param cluster_id: The cluster_id of this V1ModelVersionArchive.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1ModelVersionArchive.  # noqa: E501


        :return: The created_at of this V1ModelVersionArchive.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1ModelVersionArchive.


        :param created_at: The created_at of this V1ModelVersionArchive.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def downloads(self) -> 'str':
        """Gets the downloads of this V1ModelVersionArchive.  # noqa: E501


        :return: The downloads of this V1ModelVersionArchive.  # noqa: E501
        :rtype: str
        """
        return self._downloads

    @downloads.setter
    def downloads(self, downloads: 'str'):
        """Sets the downloads of this V1ModelVersionArchive.


        :param downloads: The downloads of this V1ModelVersionArchive.  # noqa: E501
        :type: str
        """

        self._downloads = downloads

    @property
    def metadata(self) -> 'dict(str, str)':
        """Gets the metadata of this V1ModelVersionArchive.  # noqa: E501


        :return: The metadata of this V1ModelVersionArchive.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: 'dict(str, str)'):
        """Sets the metadata of this V1ModelVersionArchive.


        :param metadata: The metadata of this V1ModelVersionArchive.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def model_id(self) -> 'str':
        """Gets the model_id of this V1ModelVersionArchive.  # noqa: E501


        :return: The model_id of this V1ModelVersionArchive.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id: 'str'):
        """Sets the model_id of this V1ModelVersionArchive.


        :param model_id: The model_id of this V1ModelVersionArchive.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1ModelVersionArchive.  # noqa: E501


        :return: The project_id of this V1ModelVersionArchive.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1ModelVersionArchive.


        :param project_id: The project_id of this V1ModelVersionArchive.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1ModelVersionArchive.  # noqa: E501


        :return: The updated_at of this V1ModelVersionArchive.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1ModelVersionArchive.


        :param updated_at: The updated_at of this V1ModelVersionArchive.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def version(self) -> 'str':
        """Gets the version of this V1ModelVersionArchive.  # noqa: E501


        :return: The version of this V1ModelVersionArchive.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version: 'str'):
        """Sets the version of this V1ModelVersionArchive.


        :param version: The version of this V1ModelVersionArchive.  # noqa: E501
        :type: str
        """

        self._version = version

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ModelVersionArchive, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ModelVersionArchive') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ModelVersionArchive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1ModelVersionArchive') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
